@@ -60,7 +60,15 @@ class WoodFunction
   size_t NumFunctions() const { return 1; }
 
   //! Get the starting point.
-  arma::mat GetInitialPoint() const { return arma::mat("-3; -1; -3; -1"); }
+  template<typename MatType = arma::mat>
+  MatType GetInitialPoint() const { return MatType("-3; -1; -3; -1"); }
+
+  //! Get the final point.
+  template<typename MatType = arma::mat>
+  MatType GetFinalPoint() const { return MatType("1; 1; 1; 1"); }
+
+  //! Get the final objective.
+  double GetFinalObjective() const { return 0.0; }
 
   /**
    * Evaluate a function for a particular batch-size.
@@ -69,16 +77,18 @@ class WoodFunction
    * @param begin The first function.
    * @param batchSize Number of points to process.
    */
-  double Evaluate(const arma::mat& coordinates,
-                  const size_t begin,
-                  const size_t batchSize) const;
+  template<typename MatType>
+  typename MatType::elem_type Evaluate(const MatType& coordinates,
+                                       const size_t begin,
+                                       const size_t batchSize) const;
 
   /**
    * Evaluate a function with the given coordinates.
    *
    * @param coordinates The function coordinates.
    */
-  double Evaluate(const arma::mat& coordinates) const;
+  template<typename MatType>
+  typename MatType::elem_type Evaluate(const MatType& coordinates) const;
 
   /**
    * Evaluate the gradient of a function for a particular batch-size.
@@ -88,9 +98,10 @@ class WoodFunction
    * @param gradient The function gradient.
    * @param batchSize Number of points to process.
    */
-  void Gradient(const arma::mat& coordinates,
+  template<typename MatType, typename GradType>
+  void Gradient(const MatType& coordinates,
                 const size_t begin,
-                arma::mat& gradient,
+                GradType& gradient,
                 const size_t batchSize) const;
 
   /**
@@ -99,7 +110,8 @@ class WoodFunction
    * @param coordinates The function coordinates.
    * @param gradient The function gradient.
    */
-  void Gradient(const arma::mat& coordinates, arma::mat& gradient) const;
+  template<typename MatType, typename GradType>
+  void Gradient(const MatType& coordinates, GradType& gradient) const;
 };
 
 } // namespace test
